@@ -3,9 +3,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': './Parser/asdl_c.py',
- 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
- 'AST_ASDL': './Parser/Python.asdl',
+ 'ASDLGEN': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/asdl_c.py',
+ 'ASDLGEN_FILES': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/asdl.py /usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/asdl_c.py',
+ 'AST_ASDL': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
@@ -25,11 +25,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe  -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.6/Python-2.7.6' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/'",
+ 'CONFIG_ARGS': "'--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.8/Python-2.7.8' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd5:lib-tk:lib-old',
- 'CPPFLAGS': '-I. -IInclude -I./Include',
+ 'CPPFLAGS': '-I. -IInclude -I/usr/obj/ports/Python-2.7.8/Python-2.7.8/Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
  'C_THREADS': 0,
  'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python2.7 /usr/local/lib/python2.7/lib-dynload',
@@ -61,7 +61,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'GNULD': 'yes',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': './Grammar/Grammar',
+ 'GRAMMAR_INPUT': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -177,7 +177,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -185,7 +185,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBDL': 0,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBIEEE': 0,
- 'HAVE_LIBINTL_H': 0,
+ 'HAVE_LIBINTL_H': 1,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBUTIL_H': 0,
@@ -202,6 +202,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_MKFIFO': 1,
  'HAVE_MKNOD': 1,
  'HAVE_MKTIME': 1,
+ 'HAVE_MMAP': 1,
  'HAVE_MREMAP': 0,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
@@ -349,7 +350,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'sh-unknown-openbsd5.5',
+ 'HOST_GNU_TYPE': 'mips64el-unknown-openbsd5.6',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
@@ -394,7 +395,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MAINCC': 'c++ -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': './Modules/makesetup',
+ 'MAKESETUP': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Modules/makesetup',
  'MANDIR': '/usr/local/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': 'mkdir -p',
@@ -425,7 +426,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -439,7 +440,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe  -fPIC -I. -IInclude -I./Include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe  -fPIC -I. -IInclude -I/usr/obj/ports/Python-2.7.8/Python-2.7.8/Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'unsigned short',
@@ -451,7 +452,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.6/Python-2.7.6:',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/ports/Python-2.7.8/Python-2.7.8',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -465,22 +466,22 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
- 'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
@@ -494,8 +495,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.6/Python-2.7.6: ./python -Wd -3 -E -tt',
+ 'TESTPROG': '/usr/obj/ports/Python-2.7.8/Python-2.7.8/Lib/test/regrtest.py',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/ports/Python-2.7.8/Python-2.7.8 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -506,6 +507,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
+ 'VPATH': '/usr/obj/ports/Python-2.7.8/Python-2.7.8',
  'WANT_SIGFPE_HANDLER': 1,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
@@ -519,11 +521,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-2.7.6/Python-2.7.6',
- 'abs_srcdir': '/usr/obj/ports/Python-2.7.6/Python-2.7.6',
- 'build': 'sh-unknown-openbsd5.5',
+ 'abs_builddir': '/home/ports/Python-2.7.8/Python-2.7.8',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.8/Python-2.7.8',
+ 'build': 'mips64el-unknown-openbsd5.6',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'sh-unknown-openbsd5.5',
+ 'host': 'mips64el-unknown-openbsd5.6',
  'prefix': '/usr/local',
- 'srcdir': '.'}
+ 'srcdir': '/usr/obj/ports/Python-2.7.8/Python-2.7.8'}
